﻿using Blazor.Models;
using Blazor.Services;
using Microsoft.AspNetCore.Components;

namespace Blazor.Pages.Chapters;

public partial class EditChapter
{
    [Parameter]
    public int Id { get; set; }

    private ChapterModel chapterModel = new();

    [Inject]
    public IDataService DataService { get; set; }

    [Inject]
    public NavigationManager NavigationManager { get; set; }

    [Inject]
    public IWebHostEnvironment WebHostEnvironment { get; set; }

    protected override async Task OnInitializedAsync()
    {
        var chapter = await DataService.GetById(Id);

        // Set the model with the chapter
        chapterModel = new ChapterModel
        {
            Id = chapter.Id,
            Name = chapter.Name
        };
    }

    private async void HandleValidSubmit()
    {
        await DataService.Update(Id, chapterModel);
        var formData = new List<KeyValuePair<string, string>>();
        formData.Add(new KeyValuePair<string, string>("name", chapterModel.Name));


        var formContent = new FormUrlEncodedContent(formData);

        string apiUri = "https://trusting-panini.87-106-126-109.plesk.page/api/update/chapter/"+chapterModel.Id;

        using (var httpClient = new HttpClient())
        {
            var response = await httpClient.PostAsync(apiUri, formContent);

            if (response.IsSuccessStatusCode)
            {
                var responseBody = await response.Content.ReadAsStringAsync();
            }
            else
            {
                var errorResponse = await response.Content.ReadAsStringAsync();
            }
        }
        NavigationManager.NavigateTo("chapters");
    }
}
